@@ -1,4 +1,10 @@
-from .batches import get_batch_types, get_batch_type_details, get_batches
+from .batches import (
+    get_batch_types,
+    get_batch_type_details,
+    get_batches,
+    update_batch_values,
+    update_batch_feature_values,
+)
 from .data import (
     get_data_list,
     get_time_values,
@@ -14,6 +20,8 @@ __all__ = [
     "get_batch_types",
     "get_batch_type_details",
     "get_batches",
+    "update_batch_values",
+    "update_batch_feature_values",
     "get_data_list",
     "get_time_values",
     "get_batch_values",
