@@ -22,6 +22,7 @@ def get_data_list(
     measurement_id: Optional[str] = None,
     measurement_name: Optional[str] = None,
     tag_value_id: Optional[List[str]] = None,
+    include_technical_data: Optional[bool] = False,
     page: Optional[int] = None,
     page_size: Optional[int] = None,
     get_all_pages: bool = True,
@@ -47,6 +48,8 @@ def get_data_list(
         The measurement name all data should have. Cannot be used in conjunction with 'measurement_id'.
     tag_value_id: list of str, optional
         An array of tag value ids the data should have.
+    include_technical_data: bool, default False
+        Whether to include the technical data.
     page: int, optional
         Page number to retrieve. If None, the first page will be retrieved.
         The argument is ignored if 'get_all_pages' is True.
@@ -96,6 +99,7 @@ def get_data_list(
             measurement_id=measurement_id,
             measurement_name=measurement_name,
             tag_value_id=tag_value_id,
+            include_technical_data=include_technical_data,
             page=page_num,
             page_size=page_size,
             api_credentials=api_credentials,
