@@ -83,7 +83,7 @@ def get_batches(
             "start": start_date_iso,
             "end": end_date_iso,
             "name": name,
-            "feature-values": features_value_ids,
+            "feature-values": utils.join_list_query_param(features_value_ids),
             "page": page,
             "size": page_size,
         },
