@@ -23,6 +23,7 @@ def get_data_list(
     measurement_id: Optional[str] = None,
     measurement_name: Optional[str] = None,
     tag_value_id: Optional[List[str]] = None,
+    include_technical_data: Optional[bool] = False,
     page: Optional[int] = None,
     page_size: Optional[int] = None,
     api_credentials: Optional[_credentials.OIAnalyticsAPICredentials] = None,
@@ -41,6 +42,7 @@ def get_data_list(
             "measurement-id": measurement_id,
             "measurement-name": measurement_name,
             "tag-value-id": tag_value_id,
+            "include-technical-data": include_technical_data,
             "page": page,
             "size": page_size,
         },
