@@ -159,7 +159,7 @@ class FileParameter(BaseModel):
 class PeriodParameter(BaseModel):
     type: StrictStr
     sourceCodeName: StrictStr
-    value: Optional[timedelta]
+    value: Optional[str]
 
     @validator("type")
     def validate_type(cls, value):
@@ -167,13 +167,6 @@ class PeriodParameter(BaseModel):
             raise ValueError("'type' should be 'PERIOD'")
         return value
 
-    @validator("value", pre=True)
-    def parse_value(cls, value):
-        if value is None:
-            return None
-        else:
-            return pd.Timedelta(value).to_pytimedelta()
-
     @property
     def readable_value(self):
         if self.value is None:
@@ -574,9 +567,28 @@ class BatchPredicateBatchType(BaseModel):
     reference: StrictStr
 
 
+class BatchTagValue(BaseModel):
+    type: StrictStr
+    id: StrictStr
+    reference: StrictStr
+
+    @validator("type")
+    def check_type(cls, value):
+        if value != "batch-tag-value":
+            raise ValueError("Batch tag value type should be 'batch-tag-value'")
+        return value
+
+
 class BatchPredicateValue(BaseModel):
     type: StrictStr
     batchType: BatchPredicateBatchType
+    featureFilters: List[BatchTagValue]
+
+    @validator("type")
+    def check_type(cls, value):
+        if value != "batch-predicate":
+            raise ValueError("Batch predicate type should be 'batch-predicate'")
+        return value
 
 
 class BatchPredicateParameter(BaseModel):
@@ -814,80 +826,52 @@ InstanceParameter = Union[
 
 
 # Model instance
+class SingleObservationTimeContext(BaseModel):
+    type: StrictStr
+    overlappingPeriod: timedelta
+    aggregationPeriod: StrictStr
+
+    @validator("type")
+    def check_type(cls, value):
+        if value != "time":
+            raise ValueError("Single observation type should be 'time'")
+        return value
+
+    @validator("overlappingPeriod", pre=True)
+    def parse_overlapping_period(cls, value):
+        return pd.Timedelta(value).to_pytimedelta()
+
+
+class SingleObservationBatchContext(BaseModel):
+    type: StrictStr
+    batchPredicate: BatchPredicateValue
+    overlappingPeriod: timedelta
+
+    @validator("type")
+    def check_type(cls, value):
+        if value != "batch":
+            raise ValueError("Single observation type should be 'batch'")
+        return value
+
+    @validator("overlappingPeriod", pre=True)
+    def parse_overlapping_period(cls, value):
+        return pd.Timedelta(value).to_pytimedelta()
+
+
+SingleObservationContext = Union[
+    SingleObservationBatchContext, SingleObservationTimeContext
+]
+
+
 class ModelInstance(BaseModel):
     id: StrictStr
     trigger: Trigger
     active: StrictBool
     dataExchangeMode: StrictStr
+    singleObservationContext: Optional[SingleObservationContext]
     inputParameters: List[InstanceParameter]
     outputParameters: List[InstanceParameter]
 
-    def find_inputs_by_types(self, input_types: Optional[List[str]] = None):
-        if input_types is None:
-            return self.inputParameters
-        else:
-            return [
-                param for param in self.inputParameters if param.type in input_types
-            ]
-
-    def find_input_by_sourcecodename(self, source_code_name: str):
-        for param in self.inputParameters:
-            if param.sourceCodeName == source_code_name:
-                return param
-            raise KeyError(
-                f"No input parameter is referenced by the source code name {source_code_name}"
-            )
-
-    def find_outputs_by_types(self, output_types: Optional[List[str]] = None):
-        if output_types is None:
-            return self.outputParameters
-        else:
-            return [
-                param for param in self.outputParameters if param.type in output_types
-            ]
-
-    def find_output_by_sourcecodename(self, source_code_name: str):
-        for param in self.outputParameters:
-            if param.sourceCodeName == source_code_name:
-                return param
-            raise KeyError(
-                f"No output parameter is referenced by the source code name {source_code_name}"
-            )
-
-    def get_input_dict(
-        self, input_types: Optional[List[str]] = None, mode: str = "object"
-    ):
-        input_params = self.find_inputs_by_types(input_types)
-        if mode == "reference":
-            return {
-                param.sourceCodeName: param.readable_value for param in input_params
-            }
-        elif mode == "id":
-            return {
-                param.sourceCodeName: param.technical_value for param in input_params
-            }
-        elif mode == "object":
-            return {param.sourceCodeName: param.value for param in input_params}
-        else:
-            raise ValueError(f"Unknown value for 'mode': {mode}")
-
-    def get_output_dict(
-        self, output_types: Optional[List[str]] = None, mode: str = "object"
-    ):
-        output_params = self.find_outputs_by_types(output_types)
-        if mode == "reference":
-            return {
-                param.sourceCodeName: param.readable_value for param in output_params
-            }
-        elif mode == "id":
-            return {
-                param.sourceCodeName: param.technical_value for param in output_params
-            }
-        elif mode == "object":
-            return {param.sourceCodeName: param.value for param in output_params}
-        else:
-            raise ValueError(f"Unknown value for 'mode': {mode}")
-
 
 # Model execution
 class ModelExecution(BaseModel):
@@ -900,6 +884,170 @@ class ModelExecution(BaseModel):
     def set_as_default_model_execution(self):
         set_default_model_execution(self)
 
+    def find_inputs_by_types(self, input_types: Optional[List[str]] = None):
+        if input_types is None:
+            return self.pythonModelInstance.inputParameters
+        else:
+            return [
+                param
+                for param in self.pythonModelInstance.inputParameters
+                if param.type in input_types
+            ]
+
+    def find_input_by_sourcecodename(self, source_code_name: str):
+        for param in self.pythonModelInstance.inputParameters:
+            if param.sourceCodeName == source_code_name:
+                return param
+            raise KeyError(
+                f"No input parameter is referenced by the source code name {source_code_name}"
+            )
+
+    def find_outputs_by_types(self, output_types: Optional[List[str]] = None):
+        if output_types is None:
+            return self.pythonModelInstance.outputParameters
+        else:
+            return [
+                param
+                for param in self.pythonModelInstance.outputParameters
+                if param.type in output_types
+            ]
+
+    def find_output_by_sourcecodename(self, source_code_name: str):
+        for param in self.pythonModelInstance.outputParameters:
+            if param.sourceCodeName == source_code_name:
+                return param
+            raise KeyError(
+                f"No output parameter is referenced by the source code name {source_code_name}"
+            )
+
+    def get_input_dict(
+        self,
+        input_types: Optional[List[str]] = None,
+        mode: str = "object",
+        exclude_empty_values: bool = True,
+    ):
+        input_params = self.find_inputs_by_types(input_types)
+        if mode == "reference":
+            input_dict = {
+                param.sourceCodeName: param.readable_value for param in input_params
+            }
+        elif mode == "id":
+            input_dict = {
+                param.sourceCodeName: param.technical_value for param in input_params
+            }
+        elif mode == "object":
+            input_dict = {param.sourceCodeName: param.value for param in input_params}
+        else:
+            raise ValueError(f"Unknown 'mode': {mode}")
+
+        if exclude_empty_values is True:
+            input_dict = {k: v for k, v in input_dict.items() if v is not None}
+
+        return input_dict
+
+    def get_output_dict(
+        self,
+        output_types: Optional[List[str]] = None,
+        mode: str = "object",
+        exclude_empty_values: bool = True,
+    ):
+        output_params = self.find_outputs_by_types(output_types)
+        if mode == "reference":
+            output_dict = {
+                param.sourceCodeName: param.readable_value for param in output_params
+            }
+        elif mode == "id":
+            output_dict = {
+                param.sourceCodeName: param.technical_value for param in output_params
+            }
+        elif mode == "object":
+            output_dict = {param.sourceCodeName: param.value for param in output_params}
+        else:
+            raise ValueError(f"Unknown value for 'mode': {mode}")
+
+        if exclude_empty_values is True:
+            output_dict = {k: v for k, v in output_dict.items() if v is not None}
+
+            return output_dict
+
+    def get_data_input_dict(
+        self,
+        data_type: str = "any",
+        strict: bool = False,
+        mode: str = "object",
+        exclude_empty_values: bool = True,
+    ):
+        if data_type == "any":
+            input_types = [
+                "DATA",
+                "STORED_CONTINUOUS_DATA",
+                "STORED_BATCH_DATA",
+                "COMPUTED_CONTINUOUS_DATA",
+                "COMPUTED_BATCH_DATA",
+                "BATCH_TIME_DATA",
+                "BATCH_TAG_KEY",
+            ]
+        elif data_type == "time":
+            input_types = ["STORED_CONTINUOUS_DATA", "COMPUTED_CONTINUOUS_DATA"]
+            if strict is False:
+                input_types.append("DATA")
+        elif data_type == "batch":
+            input_types = [
+                "STORED_BATCH_DATA",
+                "COMPUTED_BATCH_DATA",
+                "BATCH_TIME_DATA",
+                "BATCH_TAG_KEY",
+            ]
+            if strict is False:
+                input_types.append("DATA")
+        else:
+            raise ValueError(f"Unknown 'data_type': {data_type}")
+
+        return self.get_input_dict(
+            input_types=input_types,
+            mode=mode,
+            exclude_empty_values=exclude_empty_values,
+        )
+
+    def get_data_output_dict(
+        self,
+        data_type: str = "any",
+        strict: bool = False,
+        mode: str = "object",
+        exclude_empty_values: bool = True,
+    ):
+        if data_type == "any":
+            output_types = [
+                "DATA",
+                "STORED_CONTINUOUS_DATA",
+                "STORED_BATCH_DATA",
+                "COMPUTED_CONTINUOUS_DATA",
+                "COMPUTED_BATCH_DATA",
+                "BATCH_TIME_DATA",
+                "BATCH_TAG_KEY",
+            ]
+        elif data_type == "time":
+            output_types = ["STORED_CONTINUOUS_DATA", "COMPUTED_CONTINUOUS_DATA"]
+            if strict is False:
+                output_types.append("DATA")
+        elif data_type == "batch":
+            output_types = [
+                "STORED_BATCH_DATA",
+                "COMPUTED_BATCH_DATA",
+                "BATCH_TIME_DATA",
+                "BATCH_TAG_KEY",
+            ]
+            if strict is False:
+                output_types.append("DATA")
+        else:
+            raise ValueError(f"Unknown 'data_type': {data_type}")
+
+        return self.get_output_dict(
+            output_types=output_types,
+            mode=mode,
+            exclude_empty_values=exclude_empty_values,
+        )
+
     @property
     def execution_kwargs(self):
         return {
@@ -907,18 +1055,12 @@ class ModelExecution(BaseModel):
             "test_mode": self.testMode,
             "current_execution_date": self.currentExecutionInstant,
             "last_execution_date": self.lastSuccessfulExecutionInstant,
-            "input_parameters": self.pythonModelInstance.get_input_dict(mode="object"),
-            "input_parameter_references": self.pythonModelInstance.get_input_dict(
-                mode="reference"
-            ),
-            "input_parameter_ids": self.pythonModelInstance.get_input_dict(mode="id"),
-            "output_parameters": self.pythonModelInstance.get_output_dict(
-                mode="object"
-            ),
-            "output_parameter_references": self.pythonModelInstance.get_output_dict(
-                mode="reference"
-            ),
-            "output_parameter_ids": self.pythonModelInstance.get_output_dict(mode="id"),
+            "input_parameters": self.get_input_dict(mode="object"),
+            "input_parameter_references": self.get_input_dict(mode="reference"),
+            "input_parameter_ids": self.get_input_dict(mode="id"),
+            "output_parameters": self.get_output_dict(mode="object"),
+            "output_parameter_references": self.get_output_dict(mode="reference"),
+            "output_parameter_ids": self.get_output_dict(mode="id"),
         }
 
     def get_execution_argument_value(self, argument_name: str):
