@@ -1,5 +1,6 @@
 from typing import Optional
 import requests
+import io
 
 from ... import api
 from .. import _dtos
@@ -29,4 +30,4 @@ def get_resource_file(
 
     # Output
     response.raise_for_status()
-    return response.content
+    return io.BytesIO(response.content)
